==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/IdPCsrLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdPCsrLinks
 */
@JsonPropertyOrder({ IdPCsrLinks.JSON_PROPERTY_SELF, IdPCsrLinks.JSON_PROPERTY_PUBLISH })
@JsonTypeName("IdPCsr__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class IdPCsrLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public Map<String, Object> additionalProperties = new java.util.LinkedHashMap<>();

    public Map<String, Object> getAdditionalProperties() {
        return additionalProperties;
    }

    public void setAdditionalProperties(Map<String, Object> additionalProperties) {
        this.additionalProperties = additionalProperties;
    }

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_PUBLISH = "publish";
    private HrefObject publish;

    public IdPCsrLinks() {
    }

    public IdPCsrLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public IdPCsrLinks publish(HrefObject publish) {

        this.publish = publish;
        return this;
    }

    /**
     * Publish the CSR
     *
     * @return publish
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Publish the CSR")
    @JsonProperty(JSON_PROPERTY_PUBLISH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPublish() {
        return publish;
    }

    @JsonProperty(JSON_PROPERTY_PUBLISH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPublish(HrefObject publish) {
        this.publish = publish;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdPCsrLinks idPCsrLinks = (IdPCsrLinks) o;
        return Objects.equals(this.self, idPCsrLinks.self) && Objects.equals(this.publish, idPCsrLinks.publish);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, publish, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdPCsrLinks {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    publish: ").append(toIndentedString(publish)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/IdPCsrLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdPCsrLinks
 */
@JsonPropertyOrder({ IdPCsrLinks.JSON_PROPERTY_SELF, IdPCsrLinks.JSON_PROPERTY_PUBLISH })
@JsonTypeName("IdPCsr__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class IdPCsrLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public Map<String, Object> additionalProperties = new java.util.LinkedHashMap<>();

    public Map<String, Object> getAdditionalProperties() {
        return additionalProperties;
    }

    public void setAdditionalProperties(Map<String, Object> additionalProperties) {
        this.additionalProperties = additionalProperties;
    }

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_PUBLISH = "publish";
    private HrefObject publish;

    public IdPCsrLinks() {
    }

    public IdPCsrLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public IdPCsrLinks publish(HrefObject publish) {

        this.publish = publish;
        return this;
    }

    /**
     * Publish the CSR
     *
     * @return publish
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Publish the CSR")
    @JsonProperty(JSON_PROPERTY_PUBLISH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPublish() {
        return publish;
    }

    @JsonProperty(JSON_PROPERTY_PUBLISH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPublish(HrefObject publish) {
        this.publish = publish;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdPCsrLinks idPCsrLinks = (IdPCsrLinks) o;
        return Objects.equals(this.self, idPCsrLinks.self) && Objects.equals(this.publish, idPCsrLinks.publish);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, publish, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdPCsrLinks {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    publish: ").append(toIndentedString(publish)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
